package com.xkrs.controller;

import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.PictureEntity;
import com.xkrs.model.qo.PictureQo;
import com.xkrs.service.PictureService;
import com.xkrs.util.PictureQuery;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.annotation.Resource;
import java.io.IOException;
import java.util.List;
import java.util.Locale;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/20 16:01
 */
@RestController
public class PictureController {

    @Resource
    private PictureService pictureService;

    @Resource
    private PictureQuery pictureQuery;

    /**
     * 上传图片
     */
    @PostMapping("/insertPicture")
    public String insertPicture(PictureQo pictureQo, @RequestParam("filePicture") MultipartFile filePicture) throws IOException {
        return pictureService.insertPicture(pictureQo, filePicture);
    }

    /**
     * 查询图片
     */
    @GetMapping("/selectPicture")
    public String selectPicture(@RequestParam("lotNo") String lotNo,
                                @RequestParam("machineNo") String machineNo,
                                @RequestParam("materialNo") String materialNo,
                                @RequestParam("modelNo") String modelNo,
                                @RequestParam("partNo") String partNo) {
        Locale locale = LocaleContextHolder.getLocale();
        List<PictureEntity> pictureEntities = pictureQuery.selectPicture(lotNo, machineNo, materialNo, modelNo, partNo);
        if (pictureEntities.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该零件的图片！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, pictureEntities, locale);
    }
}
